# monstrelib

![Tests](https://github.com/Charifjaz/monstrelib/actions/workflows/tests.yml/badge.svg?branch=main)
[![codecov](https://codecov.io/gh/Charifjaz/monstrelib/branch/main/graph/badge.svg)](https://codecov.io/gh/Charifjaz/monstrelib)

Une petite librairie Python pour tester CI/CD 😎
